==> qtwebengine-everywhere-opensource-src-6.2.7.zip: qtwebengine-everywhere-src-6.2.7/src/3rdparty/chromium/chrome/browser/ui/webui/chromeos/login/app_downloading_screen_handler.cc <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/chromeos/login/app_downloading_screen_handler.h"

#include "ash/components/arc/arc_prefs.h"
#include "ash/constants/ash_features.h"
#include "chrome/browser/ash/login/screens/app_downloading_screen.h"
#include "chrome/browser/profiles/profile_manager.h"
#include "chrome/grit/generated_resources.h"
#include "components/login/localized_values_builder.h"
#include "components/prefs/pref_service.h"
#include "ui/base/resource/resource_bundle.h"
#include "ui/chromeos/devicetype_utils.h"

namespace {

int GetNumberOfUserSelectedApps() {
  const Profile* profile = ProfileManager::GetActiveUserProfile();
  const PrefService* pref_service = profile->GetPrefs();
  return static_cast<int>(
      pref_service->Get(arc::prefs::kArcFastAppReinstallPackages)
          ->GetListDeprecated()
          .size());
}

}  // namespace

namespace chromeos {

constexpr StaticOobeScreenId AppDownloadingScreenView::kScreenId;

AppDownloadingScreenHandler::AppDownloadingScreenHandler()
    : BaseScreenHandler(kScreenId) {
  set_user_acted_method_path_deprecated("login.AppDownloadingScreen.userActed");
}

AppDownloadingScreenHandler::~AppDownloadingScreenHandler() {
  if (screen_)
    screen_->OnViewDestroyed(this);
}

void AppDownloadingScreenHandler::DeclareLocalizedValues(
    ::login::LocalizedValuesBuilder* builder) {
  builder->AddF("appDownloadingScreenDescription",
                IDS_LOGIN_APP_DOWNLOADING_SCREEN_DESCRIPTION,
                ui::GetChromeOSDeviceName());
  builder->Add("appDownloadingContinueSetup",
               IDS_LOGIN_APP_DOWNLOADING_SCREEN_NEXT);
  builder->Add("appDownloadingScreenTitle",
               IDS_LOGIN_APP_DOWNLOADING_SCREEN_TITLE);
}

void AppDownloadingScreenHandler::RegisterMessages() {
  BaseScreenHandler::RegisterMessages();
}

void AppDownloadingScreenHandler::Bind(AppDownloadingScreen* screen) {
  screen_ = screen;
  BaseScreenHandler::SetBaseScreenDeprecated(screen);
}

void AppDownloadingScreenHandler::Show() {
  base::Value::Dict data;
  data.Set("numOfApps", GetNumberOfUserSelectedApps());
  ShowInWebUI(std::move(data));
}

void AppDownloadingScreenHandler::Hide() {}

void AppDownloadingScreenHandler::InitializeDeprecated() {}

}  // namespace chromeos

==> qtwebengine-everywhere-opensource-src-6.2.13.zip: qtwebengine-everywhere-src-6.2.13/src/3rdparty/chromium/chrome/browser/ui/webui/chromeos/login/app_downloading_screen_handler.cc <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/chromeos/login/app_downloading_screen_handler.h"

#include "ash/components/arc/arc_prefs.h"
#include "chrome/browser/profiles/profile_manager.h"
#include "chrome/grit/generated_resources.h"
#include "components/login/localized_values_builder.h"
#include "components/prefs/pref_service.h"
#include "ui/base/resource/resource_bundle.h"
#include "ui/chromeos/devicetype_utils.h"

namespace {

int GetNumberOfUserSelectedApps() {
  const Profile* profile = ProfileManager::GetActiveUserProfile();
  const PrefService* pref_service = profile->GetPrefs();
  return static_cast<int>(
      pref_service->GetList(arc::prefs::kArcFastAppReinstallPackages).size());
}

}  // namespace

namespace chromeos {

AppDownloadingScreenHandler::AppDownloadingScreenHandler()
    : BaseScreenHandler(kScreenId) {}

AppDownloadingScreenHandler::~AppDownloadingScreenHandler() = default;

void AppDownloadingScreenHandler::DeclareLocalizedValues(
    ::login::LocalizedValuesBuilder* builder) {
  builder->AddF("appDownloadingScreenDescription",
                IDS_LOGIN_APP_DOWNLOADING_SCREEN_DESCRIPTION,
                ui::GetChromeOSDeviceName());
  builder->Add("appDownloadingContinueSetup",
               IDS_LOGIN_APP_DOWNLOADING_SCREEN_NEXT);
  builder->Add("appDownloadingScreenTitle",
               IDS_LOGIN_APP_DOWNLOADING_SCREEN_TITLE);
}

void AppDownloadingScreenHandler::Show() {
  base::Value::Dict data;
  data.Set("numOfApps", GetNumberOfUserSelectedApps());
  ShowInWebUI(std::move(data));
}

}  // namespace chromeos
